# Releasify

[![Build Status](https://travis-ci.org/steven-mercatante/releasify.svg?branch=master)](https://travis-ci.org/steven-mercatante/releasify)
[![codecov](https://codecov.io/gh/steven-mercatante/releasify/branch/master/graph/badge.svg)](https://codecov.io/gh/steven-mercatante/releasify)

## What is this?
A tool that lets you quickly and easily create [semantic version](https://semver.org/) releases to GitHub repositories. It automatically builds the release body by combining all merge commit messages since the last release. Works great on its own, or as part of a continuous integration pipeline.

## How do I use it?
This is a low level tool. Check out [releasify-web](https://github.com/steven-mercatante/releasify-web) for a RESTful API interface to this library.
